#!/usr/bin/env python

import os
from dm.common.cli.dmRestSessionCli import DmRestSessionCli
from dm.common.utility.osUtility import OsUtility
from dm.common.utility.configurationManager import ConfigurationManager

class DaqWebServiceSessionCli(DmRestSessionCli):
    """ DM DAQ web service session cli class. """

    DEFAULT_SESSION_CACHE_FILE = OsUtility.getUserHomeDir() + '/.dm/.daq.session.cache'

    def __init__(self, validArgCount=0):
        DmRestSessionCli.__init__(self, validArgCount)
        ConfigurationManager.getInstance().setSessionCacheFile(DaqWebServiceSessionCli.DEFAULT_SESSION_CACHE_FILE)

    def getDefaultServiceHost(self):
        return ConfigurationManager.getInstance().getDaqWebServiceHost()

    def getDefaultServicePort(self):
        return ConfigurationManager.getInstance().getDaqWebServicePort()

    def getId(self):
        return self.options.id

    def getExperimentName(self):
        return self.options.experimentName

    def getDataDirectory(self):
        dataDirectory = self.options.dataDirectory
        if not dataDirectory:
            return None
        if dataDirectory.find('://') < 0:
            fileServerUrl = os.environ.get('DM_FILE_SERVER_URL')
            dataDirectory = '%s%s' % (fileServerUrl, dataDirectory)
        replacementMap = os.environ.get('DM_DATA_DIRECTORY_MAP', '')
        (scheme, host, port, dirPath) = FtpUtility.parseUrl(dataDirectory)
        if dirPath and replacementMap:
            # Map entries are expected to be in the form
            # <original>|<replacement>;<original>|<replacement>;...
            for entry in replacementMap.split(';'):
                original = entry.split('|')[0]
                replacement = entry.split('|')[1]
                dirPath = dataDirectory.replace(original,replacement)
        return FtpUtility.assembleUrl(scheme, host, port, dirPath)

